@@ -199,7 +199,7 @@ nautilus_drag_build_selection_list (GtkSelectionData *data)
 		oldp = p;
 	}
 
-	return result;
+	return g_list_reverse (result);
 }
 
 static gboolean
@@ -368,6 +368,7 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 	const char *dropped_uri;
 	GFile *target, *dropped;
 	GdkDragAction actions;
+	NautilusFile *target_file;
 
 	if (target_uri_string == NULL) {
 		*action = 0;
@@ -388,6 +389,7 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 	}
 	
 	dropped_uri = ((NautilusDragSelectionItem *)items->data)->uri;
+	target_file = nautilus_file_get_existing_by_uri (dropped_uri);
 	
 	/*
 	 * Check for trash URI.  We do a find_directory for any Trash directory.
@@ -400,13 +402,14 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 			*action = GDK_ACTION_MOVE;
 		}
 
+		nautilus_file_unref (target_file);
 		return;
 
-	} else if (g_str_has_prefix (target_uri_string, NAUTILUS_COMMAND_SPECIFIER) ||
-		   g_str_has_prefix (target_uri_string, NAUTILUS_DESKTOP_COMMAND_SPECIFIER) ) {
+	} else if (target_file != NULL && nautilus_file_is_launcher (target_file)) {
 		if (actions & GDK_ACTION_MOVE) {
 			*action = GDK_ACTION_MOVE;
 		}
+		nautilus_file_unref (target_file);
 		return;
 	} else if (eel_uri_is_desktop (target_uri_string)) {
 		target = nautilus_get_desktop_location ();
@@ -416,18 +419,22 @@ nautilus_drag_default_drop_action_for_icons (GdkDragContext *context,
 				*action = GDK_ACTION_MOVE;
 			}
 			
+			nautilus_file_unref (target_file);
 			return;
 		}
 	} else {
 		target = g_file_new_for_uri (target_uri_string);
 	}
 
+	nautilus_file_unref (target_file);
+	
 	/* Compare the first dropped uri with the target uri for same fs match. */
 	dropped = g_file_new_for_uri (dropped_uri);
 	same_fs = check_same_fs (target, dropped);
-	target_is_source_parent = g_file_contains_file (target, dropped);
+	target_is_source_parent = g_file_has_prefix (dropped, target);
 	
-	if (same_fs || target_is_source_parent) {
+	if (same_fs || target_is_source_parent ||
+	    g_file_has_uri_scheme (dropped, "trash")) {
 		if (actions & GDK_ACTION_MOVE) {
 			*action = GDK_ACTION_MOVE;
 		} else {
