@@ -32,12 +32,13 @@
 /* Drag & Drop target names. */
 #define NAUTILUS_ICON_DND_GNOME_ICON_LIST_TYPE  "x-special/gnome-icon-list"
 #define NAUTILUS_ICON_DND_URI_LIST_TYPE         "text/uri-list"
-#define NAUTILUS_ICON_DND_TEXT_TYPE             "text/plain"
-#define NAUTILUS_ICON_DND_URL_TYPE	        "_NETSCAPE_URL"
+#define NAUTILUS_ICON_DND_NETSCAPE_URL_TYPE	"_NETSCAPE_URL"
 #define NAUTILUS_ICON_DND_COLOR_TYPE            "application/x-color"
 #define NAUTILUS_ICON_DND_BGIMAGE_TYPE          "property/bgimage"
 #define NAUTILUS_ICON_DND_KEYWORD_TYPE          "property/keyword"
 #define NAUTILUS_ICON_DND_RESET_BACKGROUND_TYPE "x-special/gnome-reset-background"
+#define NAUTILUS_ICON_DND_ROOTWINDOW_DROP_TYPE  "application/x-rootwindow-drop"
+#define NAUTILUS_ICON_DND_XDNDDIRECTSAVE_TYPE	"XdndDirectSave0" /* XDS Protocol Type */
 
 /* Item of the drag selection list */
 typedef struct {
@@ -51,17 +52,21 @@ typedef struct {
 typedef enum {
 	NAUTILUS_ICON_DND_GNOME_ICON_LIST,
 	NAUTILUS_ICON_DND_URI_LIST,
-	NAUTILUS_ICON_DND_URL,
+	NAUTILUS_ICON_DND_NETSCAPE_URL,
 	NAUTILUS_ICON_DND_COLOR,
 	NAUTILUS_ICON_DND_BGIMAGE,
 	NAUTILUS_ICON_DND_KEYWORD,
 	NAUTILUS_ICON_DND_TEXT,
-	NAUTILUS_ICON_DND_RESET_BACKGROUND
+	NAUTILUS_ICON_DND_RESET_BACKGROUND,
+	NAUTILUS_ICON_DND_XDNDDIRECTSAVE,
+	NAUTILUS_ICON_DND_ROOTWINDOW_DROP
 } NautilusIconDndTargetType;
 
 typedef enum {
 	NAUTILUS_DND_ACTION_FIRST = GDK_ACTION_ASK << 1,
-	NAUTILUS_DND_ACTION_SET_AS_BACKGROUND = NAUTILUS_DND_ACTION_FIRST << 0
+	NAUTILUS_DND_ACTION_SET_AS_BACKGROUND = NAUTILUS_DND_ACTION_FIRST << 0,
+	NAUTILUS_DND_ACTION_SET_AS_FOLDER_BACKGROUND = NAUTILUS_DND_ACTION_FIRST << 1,
+	NAUTILUS_DND_ACTION_SET_AS_GLOBAL_BACKGROUND = NAUTILUS_DND_ACTION_FIRST << 2
 } NautilusDndAction;
 
 /* drag&drop-related information. */
@@ -72,6 +77,7 @@ typedef struct {
 	gboolean got_drop_data_type;
 	NautilusIconDndTargetType data_type;
 	GtkSelectionData *selection_data;
+	char *direct_save_uri;
 
 	/* Start of the drag, in window coordinates. */
 	int start_x, start_y;
@@ -103,18 +109,23 @@ typedef void 		(* NautilusDragEachSelectedItemIterator)	(NautilusDragEachSelecte
 
 void                        nautilus_drag_init                          (NautilusDragInfo                     *drag_info,
 									 const GtkTargetEntry                 *drag_types,
-									 int                                   drag_type_count);
+									 int                                   drag_type_count,
+									 gboolean                              add_text_targets);
 void                        nautilus_drag_finalize                      (NautilusDragInfo                     *drag_info);
 NautilusDragSelectionItem  *nautilus_drag_selection_item_new            (void);
 void                        nautilus_drag_destroy_selection_list        (GList                                *selection_list);
 GList 		           *nautilus_drag_build_selection_list          (GtkSelectionData                     *data);
 gboolean                    nautilus_drag_items_local                   (const char                           *target_uri,
 									 const GList                          *selection_list);
+gboolean                    nautilus_drag_uris_local                    (const char                           *target_uri,
+									 const GList                          *source_uri_list);
 gboolean                    nautilus_drag_items_in_trash                (const GList                          *selection_list);
+gboolean                    nautilus_drag_items_on_desktop              (const GList                          *selection_list);
 void                        nautilus_drag_default_drop_action_for_icons (GdkDragContext                       *context,
 									 const char                           *target_uri,
 									 const GList                          *items,
 									 int                                  *action);
+GdkDragAction               nautilus_drag_default_drop_action_for_netscape_url (GdkDragContext                       *context);
 gboolean                    nautilus_drag_drag_data_get                 (GtkWidget                            *widget,
 									 GdkDragContext                       *context,
 									 GtkSelectionData                     *selection_data,
@@ -124,7 +135,12 @@ gboolean                    nautilus_drag_drag_data_get                 (GtkWidg
 									 NautilusDragEachSelectedItemIterator  each_selected_item_iterator);
 int                         nautilus_drag_modifier_based_action         (int                                   default_action,
 									 int                                   non_default_action);
-GdkDragAction               nautilus_drag_drop_action_ask               (GdkDragAction                         possible_actions);
+
+GdkDragAction               nautilus_drag_drop_action_ask               (GtkWidget                            *widget,
+									 GdkDragAction                         possible_actions);
+GdkDragAction               nautilus_drag_drop_background_ask           (GtkWidget                            *widget,
+									 GdkDragAction                         possible_actions);
+
 gboolean                    nautilus_drag_autoscroll_in_scroll_region   (GtkWidget                            *widget);
 void                        nautilus_drag_autoscroll_calculate_delta    (GtkWidget                            *widget,
 									 float                                *x_scroll_delta,
