@@ -218,6 +218,7 @@ void                    nautilus_file_set_attributes                    (Nautilu
 									 GFileInfo                      *attributes,
 									 NautilusFileOperationCallback   callback,
 									 gpointer                        callback_data);
+GFilesystemPreviewType  nautilus_file_get_filesystem_use_preview        (NautilusFile *file);
 
 /* Permissions. */
 gboolean                nautilus_file_can_get_permissions               (NautilusFile                   *file);
@@ -376,6 +377,7 @@ GList                  *nautilus_file_list_filter_hidden_and_backup     (GList
 /* Get the URI that's used when activating the file.
  * Getting this can require reading the contents of the file.
  */
+gboolean                nautilus_file_is_launcher                       (NautilusFile                   *file);
 gboolean                nautilus_file_has_activation_uri                (NautilusFile                   *file);
 char *                  nautilus_file_get_activation_uri                (NautilusFile                   *file);
 GFile *                 nautilus_file_get_activation_location           (NautilusFile                   *file);
