@@ -33,17 +33,7 @@
 
 #define NAUTILUS_METADATA_KEY_CONTENT_VIEWS              	"content_views"
 
-#define NAUTILUS_METADATA_KEY_DEFAULT_ACTION_TYPE	 	"default_action_type"
-#define NAUTILUS_METADATA_KEY_DEFAULT_APPLICATION	 	"default_application"
 #define NAUTILUS_METADATA_KEY_DEFAULT_COMPONENT		 	"default_component"
-#define NAUTILUS_METADATA_KEY_SHORT_LIST_APPLICATION_ADD 	"short_list_application_add"
-#define NAUTILUS_METADATA_KEY_SHORT_LIST_APPLICATION_REMOVE	"short_list_application_remove"
-#define NAUTILUS_METADATA_KEY_EXPLICIT_APPLICATION	  	"application"
-#define NAUTILUS_METADATA_SUBKEY_APPLICATION_ID		  	"id"
-#define NAUTILUS_METADATA_KEY_SHORT_LIST_COMPONENT_ADD   	"short_list_component_add"
-#define NAUTILUS_METADATA_KEY_SHORT_LIST_COMPONENT_REMOVE 	"short_list_component_remove"
-#define NAUTILUS_METADATA_KEY_EXPLICIT_COMPONENT	  	"explicit_content_view"
-#define NAUTILUS_METADATA_SUBKEY_COMPONENT_IID		  	"iid"
 
 #define NAUTILUS_METADATA_KEY_LOCATION_BACKGROUND_COLOR 	"background_color"
 #define NAUTILUS_METADATA_KEY_LOCATION_BACKGROUND_IMAGE 	"background_tile_image"
@@ -64,6 +54,10 @@
 
 #define NAUTILUS_METADATA_KEY_WINDOW_GEOMETRY			"window_geometry"
 #define NAUTILUS_METADATA_KEY_WINDOW_SCROLL_POSITION		"window_scroll_position"
+#define NAUTILUS_METADATA_KEY_WINDOW_SHOW_HIDDEN_FILES		"window_show_hidden_files"
+#define NAUTILUS_METADATA_KEY_WINDOW_MAXIMIZED			"window_maximized"
+#define NAUTILUS_METADATA_KEY_WINDOW_STICKY			"window_sticky"
+#define NAUTILUS_METADATA_KEY_WINDOW_KEEP_ABOVE			"window_keep_above"
 
 #define NAUTILUS_METADATA_KEY_SIDEBAR_BACKGROUND_COLOR   	"sidebar_background_color"
 #define NAUTILUS_METADATA_KEY_SIDEBAR_BACKGROUND_IMAGE   	"sidebar_background_tile_image"
@@ -71,7 +65,6 @@
 #define NAUTILUS_METADATA_KEY_SIDEBAR_TAB_COLOR		 	"sidebar_tab_color"
 #define NAUTILUS_METADATA_KEY_SIDEBAR_TITLE_TAB_COLOR	 	"sidebar_title_tab_color"
 
-#define NAUTILUS_METADATA_KEY_NOTES                      	"notes"
 #define NAUTILUS_METADATA_KEY_ANNOTATION                 	"annotation"
 #define NAUTILUS_METADATA_KEY_ICON_POSITION              	"icon_position"
 #define NAUTILUS_METADATA_KEY_ICON_SCALE                 	"icon_scale"
