@@ -48,16 +48,7 @@
 #include <gtk/gtkwindow.h>
 #include <gtk/gtkstock.h>
 #include <glib/gi18n.h>
-#include <libgnome/gnome-config.h>
-#include <libgnome/gnome-desktop-item.h>
-#include <libgnome/gnome-macros.h>
-#include <libgnomevfs/gnome-vfs-ops.h>
-#include <libgnomevfs/gnome-vfs-async-ops.h>
-#include <libgnomevfs/gnome-vfs-mime-utils.h>
-#include <libgnomevfs/gnome-vfs-uri.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
-#include <libgnomevfs/gnome-vfs-xfer.h>
-#include <libnautilus-private/nautilus-audio-player.h>
+#include <gio/gio.h>
 #include <libnautilus-private/nautilus-directory-background.h>
 #include <libnautilus-private/nautilus-directory.h>
 #include <libnautilus-private/nautilus-dnd.h>
@@ -66,7 +57,6 @@
 #include <libnautilus-private/nautilus-global-preferences.h>
 #include <libnautilus-private/nautilus-icon-container.h>
 #include <libnautilus-private/nautilus-icon-dnd.h>
-#include <libnautilus-private/nautilus-icon-factory.h>
 #include <libnautilus-private/nautilus-link.h>
 #include <libnautilus-private/nautilus-metadata.h>
 #include <libnautilus-private/nautilus-view-factory.h>
@@ -80,8 +70,7 @@
 #include <unistd.h>
 #include <esd.h>
 
-#define USE_OLD_AUDIO_PREVIEW 1
-#define READ_CHUNK_SIZE 16384
+#include "nautilus-audio-mime-types.h"
 
 #define POPUP_PATH_ICON_APPEARANCE		"/selection/Icon Appearance Items"
 
@@ -112,9 +101,10 @@ struct FMIconViewDetails
 	GtkActionGroup *icon_action_group;
 	guint icon_merge_id;
 	
-	NautilusAudioPlayerData *audio_player_data;
 	int audio_preview_timeout;
 	NautilusFile *audio_preview_file;
+	int audio_preview_child_watch;
+	GPid audio_preview_child_pid;
 
 	gboolean filter_by_screen;
 	int num_screens;
@@ -165,11 +155,6 @@ static const SortCriterion sort_criteria[] = {
 
 static gboolean default_sort_in_reverse_order = FALSE;
 static int preview_sound_auto_value;
-static gboolean gnome_esd_enabled_auto_value;
-
-#if USE_OLD_AUDIO_PREVIEW
-static pid_t audio_preview_pid = 0;
-#endif
 
 static void                 fm_icon_view_set_directory_sort_by        (FMIconView           *icon_view,
 								       NautilusFile         *file,
@@ -500,7 +485,26 @@ should_show_file_on_screen (FMDirectoryView *view, NautilusFile *file)
 static void
 fm_icon_view_remove_file (FMDirectoryView *view, NautilusFile *file, NautilusDirectory *directory)
 {
-	g_assert (directory == fm_directory_view_get_model (view));
+	/* This used to assert that 'directory == fm_directory_view_get_model (view)', but that
+	 * resulted in a lot of crash reports (bug #352592). I don't see how that trace happens.
+	 * It seems that somehow we get a files_changed event sent to the view from a directory
+	 * that isn't the model, but the code disables the monitor and signal callback handlers when
+	 * changing directories. Maybe we can get some more information when this happens.
+	 * Further discussion in bug #368178.
+	 */
+	if (directory != fm_directory_view_get_model (view)) {
+		char *file_uri, *dir_uri, *model_uri;
+		file_uri = nautilus_file_get_uri (file);
+		dir_uri = nautilus_directory_get_uri (directory);
+		model_uri = nautilus_directory_get_uri (fm_directory_view_get_model (view));
+		g_warning ("fm_icon_view_remove_file() - directory not icon view model, shouldn't happen.\n"
+			   "file: %p:%s, dir: %p:%s, model: %p:%s, view loading: %d\n"
+			   "If you see this, please add this info to http://bugzilla.gnome.org/show_bug.cgi?id=368178",
+			   file, file_uri, directory, dir_uri, fm_directory_view_get_model (view), model_uri, fm_directory_view_get_loading (view));
+		g_free (file_uri);
+		g_free (dir_uri);
+		g_free (model_uri);
+	}
 	
 	if (nautilus_icon_container_remove (get_icon_container (FM_ICON_VIEW (view)),
 					    NAUTILUS_ICON_CONTAINER_ICON_DATA (file))) {
@@ -519,7 +523,7 @@ file_has_lazy_position (FMDirectoryView *view,
 	 * icon we don't overlap that one. We don't do this in general though,
 	 * as it can cause icons moving around.
 	 */
-	lazy_position = nautilus_file_has_volume (file);
+	lazy_position = nautilus_file_can_unmount (file);
 	if (lazy_position && fm_directory_view_get_loading (view)) {
 		/* if volumes are loaded during directory load, don't mark them
 		 * as lazy. This is wrong for files that were mounted during user
@@ -1417,37 +1421,37 @@ fm_icon_view_start_renaming_file (FMDirectoryView *view,
 }
 
 static const GtkActionEntry icon_view_entries[] = {
-  { "Arrange Items", NULL, N_("Arran_ge Items") }, /* name, stock id, label */
-  { "Stretch", NULL,                               /* name, stock id */
-    N_("Str_etch Icon"), NULL,                     /* label, accelerator */
-    N_("Make the selected icon stretchable"),      /* tooltip */ 
-    G_CALLBACK (action_stretch_callback) },
-  { "Unstretch", NULL,                               /* name, stock id */
-    N_("Restore Icons' Original Si_zes"), NULL,                     /* label, accelerator */
-    N_("Restore each selected icon to its original size"),      /* tooltip */ 
-    G_CALLBACK (action_unstretch_callback) },
-  { "Clean Up", NULL,                               /* name, stock id */
-    N_("Clean _Up by Name"), NULL,                     /* label, accelerator */
-    N_("Reposition icons to better fit in the window and avoid overlapping"),      /* tooltip */ 
-    G_CALLBACK (action_clean_up_callback) },
+  /* name, stock id, label */  { "Arrange Items", NULL, N_("Arran_ge Items") }, 
+  /* name, stock id */         { "Stretch", NULL,
+  /* label, accelerator */       N_("Str_etch Icon"), NULL,
+  /* tooltip */                  N_("Make the selected icon stretchable"),
+                                 G_CALLBACK (action_stretch_callback) },
+  /* name, stock id */         { "Unstretch", NULL,
+  /* label, accelerator */       N_("Restore Icons' Original Si_zes"), NULL,
+  /* tooltip */                  N_("Restore each selected icon to its original size"),
+                                 G_CALLBACK (action_unstretch_callback) },
+  /* name, stock id */         { "Clean Up", NULL,
+  /* label, accelerator */       N_("Clean _Up by Name"), NULL,
+  /* tooltip */                  N_("Reposition icons to better fit in the window and avoid overlapping"),
+                                 G_CALLBACK (action_clean_up_callback) },
 };
 
 static const GtkToggleActionEntry icon_view_toggle_entries[] = {
-  { "Tighter Layout", NULL,                               /* name, stock id */
-    N_("Compact _Layout"), NULL,                     /* label, accelerator */
-    N_("Toggle using a tighter layout scheme"),      /* tooltip */ 
-    G_CALLBACK (action_tighter_layout_callback),
-    0 },
-  { "Reversed Order", NULL,                               /* name, stock id */
-    N_("Re_versed Order"), NULL,                     /* label, accelerator */
-    N_("Display icons in the opposite order"),      /* tooltip */ 
-    G_CALLBACK (action_reversed_order_callback),
-    0 },
-  { "Keep Aligned", NULL,                               /* name, stock id */
-    N_("_Keep Aligned"), NULL,                     /* label, accelerator */
-    N_("Keep icons lined up on a grid"),      /* tooltip */ 
-    G_CALLBACK (action_keep_aligned_callback),
-    0 },
+  /* name, stock id */      { "Tighter Layout", NULL,
+  /* label, accelerator */    N_("Compact _Layout"), NULL,
+  /* tooltip */               N_("Toggle using a tighter layout scheme"),
+                              G_CALLBACK (action_tighter_layout_callback),
+                              0 },
+  /* name, stock id */      { "Reversed Order", NULL,
+  /* label, accelerator */    N_("Re_versed Order"), NULL,
+  /* tooltip */               N_("Display icons in the opposite order"),
+                              G_CALLBACK (action_reversed_order_callback),
+                              0 },
+  /* name, stock id */      { "Keep Aligned", NULL,
+  /* label, accelerator */    N_("_Keep Aligned"), NULL,
+  /* tooltip */               N_("Keep icons lined up on a grid"),
+                              G_CALLBACK (action_keep_aligned_callback),
+                              0 },
 };
 
 static const GtkRadioActionEntry arrange_radio_entries[] = {
@@ -1678,6 +1682,16 @@ fm_icon_view_using_manual_layout (FMDirectoryView *view)
 	return !fm_icon_view_using_auto_layout (FM_ICON_VIEW (view));
 }
 
+static void
+fm_icon_view_widget_to_file_operation_position (FMDirectoryView *view,
+						GdkPoint *position)
+{
+	g_assert (FM_IS_ICON_VIEW (view));
+
+	nautilus_icon_container_widget_to_file_operation_position
+		(get_icon_container (FM_ICON_VIEW (view)), position);
+}
+
 static void
 icon_container_activate_callback (NautilusIconContainer *container,
 				  GList *file_list,
@@ -1728,139 +1742,99 @@ band_select_ended_callback (NautilusIconContainer *container,
 
 /* handle the preview signal by inspecting the mime type.  For now, we only preview local sound files. */
 
+static char **
+get_preview_argv (char *uri)
+{
+	char *command;
+	char **argv;
+	int i;
+
+	command = g_find_program_in_path ("totem-audio-preview");
+	if (command) {
+		argv = g_new (char *, 3);
+		argv[0] = command;
+		argv[1] = g_strdup (uri);
+		argv[2] = NULL;
+
+		return argv;
+	}
+		
+	command = g_find_program_in_path ("gst-launch-0.10");
+	if (command) {
+		argv = g_new (char *, 10);
+		i = 0;
+		argv[i++] = command;
+		argv[i++] = g_strdup ("playbin");
+		argv[i++] = g_strconcat ("uri=", uri, NULL);
+		/* do not display videos */
+		argv[i++] = g_strdup ("current-video=-1");
+		argv[i++] = NULL;
+		return argv;
+	}
+
+	return NULL;
+}
+
+static void
+audio_child_died (GPid     pid,
+		  gint     status,
+		  gpointer data)
+{
+	FMIconView *icon_view;
+
+	icon_view = FM_ICON_VIEW (data);
+
+	icon_view->details->audio_preview_child_watch = 0;
+	icon_view->details->audio_preview_child_pid = 0;
+}
+
 /* here's the timer task that actually plays the file using mpg123, ogg123 or play. */
 /* FIXME bugzilla.gnome.org 41258: we should get the application from our mime-type stuff */
 static gboolean
 play_file (gpointer callback_data)
 {
-#if USE_OLD_AUDIO_PREVIEW	
 	NautilusFile *file;
 	FMIconView *icon_view;
-	FILE *sound_process;
-	char *file_uri;
-	char *suffix;
-	char *mime_type;
-	const char *command_str;
-	gboolean is_mp3;
-	gboolean is_ogg;
-	pid_t mp3_pid;
-	
-	GnomeVFSResult result;
-	GnomeVFSHandle *handle;
-	char *buffer;
-	const char *audio_device = NULL;
-	GnomeVFSFileSize bytes_read;
+	GPid child_pid;
+	char **argv;
+	GError *error;
+	char *uri;
 
-	audio_device = g_getenv ("AUDIODEV");
 	icon_view = FM_ICON_VIEW (callback_data);
 	
+	/* Stop timeout */
+	icon_view->details->audio_preview_timeout = 0;
+
 	file = icon_view->details->audio_preview_file;
-	file_uri = nautilus_file_get_uri (file);
-	mime_type = nautilus_file_get_mime_type (file);
-	is_mp3 = eel_strcasecmp (mime_type, "audio/mpeg") == 0;
-	is_ogg = eel_strcasecmp (mime_type, "application/ogg") == 0 ||
-                eel_strcasecmp (mime_type, "application/x-ogg") == 0;
-	
-	mp3_pid = fork ();
-	if (mp3_pid == (pid_t) 0) {
-		/* Set the group (session) id to this process for future killing. */
-		setsid();
-		if (is_mp3) {
-			command_str = "mpg123 -y -q -";
-		} else if (is_ogg) {
-			command_str = "ogg123 -q -";
-		} else {
-			suffix = strrchr(file_uri, '.');
-			if (suffix == NULL) {
-				suffix = "wav";
-			} else {
-				suffix += 1; /* skip the period */
-			}
-			if (audio_device) {
-				command_str = g_strdup_printf("play -d %s -t %s -", audio_device, suffix);
-			} else {
-				command_str = g_strdup_printf("play -t %s -", suffix);
-			}
-		}
-
-		/* read the file with gnome-vfs, feeding it to the sound player's standard input */
-		/* First, open the file. */
-		result = gnome_vfs_open (&handle, file_uri, GNOME_VFS_OPEN_READ);
-		if (result != GNOME_VFS_OK) {
-			_exit (0);
-		}
-			
-		/* since the uri could be local or remote, we launch the sound player with popen and feed it
-		 * the data by fetching it with gnome_vfs
-		 */
-		sound_process = popen(command_str, "w");
-		if (sound_process == 0) {
-			/* Close the file. */
-			result = gnome_vfs_close (handle);			
-			_exit (0);
-		}
-			
-		/* allocate a buffer. */
-		buffer = g_malloc(READ_CHUNK_SIZE);
-			
-		/* read and write a chunk at a time, until we're done */
-		do {
-			result = gnome_vfs_read (handle,
-					buffer,
-					READ_CHUNK_SIZE,
-					&bytes_read);
-			if (result != GNOME_VFS_OK && result != GNOME_VFS_ERROR_EOF) {
-				g_free (buffer);
-				gnome_vfs_close (handle);
-				break;
-			}
-
-			/* pass the data the buffer to the sound process by writing to it */
-			fwrite(buffer, 1, bytes_read, sound_process);
-
-		} while (result == GNOME_VFS_OK);
-
-		/* Close the file. */
-		result = gnome_vfs_close (handle);			
-		g_free(buffer);
-		pclose(sound_process);
-		_exit (0);
-	} else if (mp3_pid > (pid_t) 0) {
-		if (audio_preview_pid > 0) {
-			kill (-audio_preview_pid, SIGTERM);
-			waitpid (audio_preview_pid, NULL, 0);
-		}
-		audio_preview_pid = mp3_pid;
+	uri = nautilus_file_get_uri (file);
+	argv = get_preview_argv (uri);
+	g_free (uri);
+	if (argv == NULL) {
+		return FALSE;
 	}
-		
-	g_free (file_uri);
-	g_free (mime_type);
 
-	icon_view->details->audio_preview_timeout = 0;
-#else
-	char *file_path, *file_uri, *mime_type;
-	gboolean is_mp3;
-	FMIconView *icon_view;
-	
-	icon_view = FM_ICON_VIEW (callback_data);
-		
-	file_uri = nautilus_file_get_uri (icon_view->details->audio_preview_file);
-	file_path = gnome_vfs_get_local_path_from_uri (file_uri);
-	mime_type = nautilus_file_get_mime_type (icon_view->details->audio_preview_file);
-
-	is_mp3 = eel_strcasecmp (mime_type, "audio/mpeg") == 0;
-
-	if (file_path != NULL && !is_mp3) {
-		icon_view->details->audio_player_data = nautilus_audio_player_play (file_path);
+	error = NULL;
+	if (!g_spawn_async_with_pipes (NULL,
+				       argv,
+				       NULL, 
+				       G_SPAWN_STDOUT_TO_DEV_NULL | G_SPAWN_STDERR_TO_DEV_NULL,
+				       NULL,
+				       NULL /* user_data */,
+				       &child_pid,
+				       NULL, NULL, NULL,
+				       &error)) {
+		g_strfreev (argv);
+		g_warning ("Error spawning sound preview: %s\n", error->message);
+		g_error_free (error);
+		return FALSE;
 	}
-	
-	g_free (file_uri);
-	g_free (file_path);	
-	g_free (mime_type);
+	g_strfreev (argv);
 
-	icon_view->details->audio_preview_timeout = 0;
-	icon_view->details->audio_preview_file = NULL;
-#endif
+	icon_view->details->audio_preview_child_watch =
+		g_child_watch_add (child_pid,
+				   audio_child_died, NULL);
+	icon_view->details->audio_preview_child_pid = child_pid;
+	
 	return FALSE;
 }
 
@@ -1876,19 +1850,13 @@ static void
 preview_audio (FMIconView *icon_view, NautilusFile *file, gboolean start_flag)
 {		
 	/* Stop current audio playback */
-#if USE_OLD_AUDIO_PREVIEW
-	if (audio_preview_pid > 0) {
-		kill (-audio_preview_pid, SIGTERM);
-		waitpid (audio_preview_pid, NULL, 0);
-		audio_preview_pid = 0;
+	if (icon_view->details->audio_preview_child_pid != 0) {
+		kill (icon_view->details->audio_preview_child_pid, SIGTERM);
+		g_source_remove (icon_view->details->audio_preview_child_watch);
+		waitpid (icon_view->details->audio_preview_child_pid, NULL, 0);
+		icon_view->details->audio_preview_child_pid = 0;
 	}
-#else
-	if (icon_view->details->audio_player_data != NULL) {
-		nautilus_audio_player_stop (icon_view->details->audio_player_data);
-		g_free (icon_view->details->audio_player_data);
-		icon_view->details->audio_player_data = NULL;
-	}
-#endif
+	
 	if (icon_view->details->audio_preview_timeout != 0) {
 		g_source_remove (icon_view->details->audio_preview_timeout);
 		icon_view->details->audio_preview_timeout = 0;
@@ -1896,31 +1864,46 @@ preview_audio (FMIconView *icon_view, NautilusFile *file, gboolean start_flag)
 			
 	if (start_flag) {
 		icon_view->details->audio_preview_file = file;
-#if USE_OLD_AUDIO_PREVIEW			
 		icon_view->details->audio_preview_timeout = g_timeout_add (1000, play_file, icon_view);
-#else
-		/* FIXME: Need to kill the existing timeout if there is one? */
-		icon_view->details->audio_preview_timeout = g_timeout_add (1000, play_file, icon_view);
-#endif
 	}
 }
 
+static gboolean
+sound_preview_type_supported (NautilusFile *file)
+{
+	char *mime_type;
+	guint i;
+	
+	mime_type = nautilus_file_get_mime_type (file);
+	if (mime_type == NULL) {
+ 		return FALSE;
+	}
+	for (i = 0; i < G_N_ELEMENTS (audio_mime_types); i++) {
+		if (g_content_type_is_a (mime_type, audio_mime_types[i])) {
+			g_free (mime_type);
+			return TRUE;
+		}
+	}
+	
+	g_free (mime_type);
+	return FALSE;
+}
+
+
 static gboolean
 should_preview_sound (NautilusFile *file)
 {
-	char *uri;
+	GFile *location;
+	GFilesystemPreviewType use_preview;
 
-	/* Check gnome config sound preference */
-	if (!gnome_esd_enabled_auto_value) {
+	use_preview = nautilus_file_get_filesystem_use_preview (file);
+
+	location = nautilus_file_get_location (file);
+	if (g_file_has_uri_scheme (location, "burn")) {
+		g_object_unref (location);
 		return FALSE;
 	}
-
-	uri = nautilus_file_get_uri (file);
-	if (uri && eel_istr_has_prefix (uri, "burn:")) {
-		g_free (uri);
-		return FALSE;
-	}
-	g_free (uri);
+	g_object_unref (location);
 
 	/* Check user performance preference */	
 	if (preview_sound_auto_value == NAUTILUS_SPEED_TRADEOFF_NEVER) {
@@ -1928,33 +1911,23 @@ should_preview_sound (NautilusFile *file)
 	}
 		
 	if (preview_sound_auto_value == NAUTILUS_SPEED_TRADEOFF_ALWAYS) {
-		return TRUE;
+		if (use_preview == G_FILESYSTEM_PREVIEW_TYPE_NEVER) {
+			return FALSE;
+		} else {
+			return TRUE;
+		}
 	}
 	
-	return nautilus_file_is_local (file);
-}
-
-static inline gboolean
-can_play_sound (void)
-{
-	int open_result;
-
-#if USE_OLD_AUDIO_PREVIEW			
-	/* first see if there's already one in progress; if so, return true */
-	if (audio_preview_pid > 0) {
+	if (use_preview == G_FILESYSTEM_PREVIEW_TYPE_NEVER) {
+		/* file system says to never preview anything */
+		return FALSE;
+	} else if (use_preview == G_FILESYSTEM_PREVIEW_TYPE_IF_LOCAL) {
+		/* file system says we should treat file as if it's local */
 		return TRUE;
+	} else {
+		/* only local files */
+		return nautilus_file_is_local (file);
 	}
-#endif
-
-	/* Now check and see if system has audio out capabilites */
-        open_result = esd_open_sound (NULL);
-        if (open_result == -1) {
-                return FALSE;
-        }
-
-	esd_close (open_result);
-
-	return TRUE;
 }
 
 static int
@@ -1964,27 +1937,19 @@ icon_container_preview_callback (NautilusIconContainer *container,
 				 FMIconView *icon_view)
 {
 	int result;
-	char *mime_type, *file_name, *message;
+	char *file_name, *message;
 		
 	result = 0;
 	
 	/* preview files based on the mime_type. */
 	/* at first, we just handle sounds */
 	if (should_preview_sound (file)) {
-		mime_type = nautilus_file_get_mime_type (file);
-
-		if ((eel_istr_has_prefix (mime_type, "audio/")
-		     || eel_istr_has_prefix (mime_type, "application/ogg")
-		     || eel_istr_has_prefix (mime_type, "application/x-ogg"))
-		    && eel_strcasecmp (mime_type, "audio/x-pn-realaudio") != 0
-		    && eel_strcasecmp (mime_type, "audio/x-mpegurl") != 0
-		    && can_play_sound ()) {
+		if (sound_preview_type_supported (file)) {
 			result = 1;
 			preview_audio (icon_view, file, start_flag);
-		}	
-		g_free (mime_type);
+		}
 	}
-	
+
 	/* Display file name in status area at low zoom levels, since
 	 * the name is not displayed or hard to read in the icon view.
 	 */
@@ -2463,7 +2428,7 @@ fm_icon_view_update_click_mode (FMIconView *icon_view)
 						       click_mode == NAUTILUS_CLICK_POLICY_SINGLE);
 }
 
-static void
+static NautilusIconContainer *
 create_icon_container (FMIconView *icon_view)
 {
 	NautilusIconContainer *icon_container;
@@ -2522,31 +2487,36 @@ create_icon_container (FMIconView *icon_view)
 	fm_icon_view_update_click_mode (icon_view);
 
 	gtk_widget_show (GTK_WIDGET (icon_container));
+
+	return icon_container;
 }
 
 /* Handles an URL received from Mozilla */
 static void
-icon_view_handle_url (NautilusIconContainer *container, const char *encoded_url,
-		      GdkDragAction action, int x, int y, FMIconView *view)
+icon_view_handle_netscape_url (NautilusIconContainer *container, const char *encoded_url,
+			       const char *target_uri,
+			       GdkDragAction action, int x, int y, FMIconView *view)
 {
-	fm_directory_view_handle_url_drop (FM_DIRECTORY_VIEW (view),
-					   encoded_url, action, x, y);
+	fm_directory_view_handle_netscape_url_drop (FM_DIRECTORY_VIEW (view),
+						    encoded_url, target_uri, action, x, y);
 }
 
 static void
 icon_view_handle_uri_list (NautilusIconContainer *container, const char *item_uris,
+			   const char *target_uri,
 			   GdkDragAction action, int x, int y, FMIconView *view)
 {
 	fm_directory_view_handle_uri_list_drop (FM_DIRECTORY_VIEW (view),
-						item_uris, action, x, y);
+						item_uris, target_uri, action, x, y);
 }
 
 static void
 icon_view_handle_text (NautilusIconContainer *container, const char *text,
+		       const char *target_uri,
 		       GdkDragAction action, int x, int y, FMIconView *view)
 {
 	fm_directory_view_handle_text_drop (FM_DIRECTORY_VIEW (view),
-					    text, action, x, y);
+					    text, target_uri, action, x, y);
 }
 
 static char *
@@ -2578,7 +2548,7 @@ icon_view_scroll_to_file (NautilusView *view,
 	if (uri != NULL) {
 		/* Only if existing, since we don't want to add the file to
 		   the directory if it has been removed since then */
-		file = nautilus_file_get_existing (uri);
+		file = nautilus_file_get_existing_by_uri (uri);
 		if (file != NULL) {
 			nautilus_icon_container_scroll_to_icon (get_icon_container (icon_view),
 								NAUTILUS_ICON_CONTAINER_ICON_DATA (file));
@@ -2636,6 +2606,7 @@ fm_icon_view_class_init (FMIconViewClass *klass)
         fm_directory_view_class->text_attribute_names_changed = fm_icon_view_text_attribute_names_changed;
         fm_directory_view_class->update_menus = fm_icon_view_update_menus;
 	fm_directory_view_class->using_manual_layout = fm_icon_view_using_manual_layout;
+	fm_directory_view_class->widget_to_file_operation_position = fm_icon_view_widget_to_file_operation_position;
 
 	klass->clean_up = fm_icon_view_real_clean_up;
 	klass->supports_auto_layout = real_supports_auto_layout;
@@ -2675,6 +2646,7 @@ static void
 fm_icon_view_init (FMIconView *icon_view)
 {
 	static gboolean setup_sound_preview = FALSE;
+	NautilusIconContainer *icon_container;
 
         g_return_if_fail (GTK_BIN (icon_view)->child == NULL);
 
@@ -2682,15 +2654,17 @@ fm_icon_view_init (FMIconView *icon_view)
 	icon_view->details->sort = &sort_criteria[0];
 	icon_view->details->filter_by_screen = FALSE;
 
-	create_icon_container (icon_view);
+	icon_container = create_icon_container (icon_view);
+
+	/* Set our default layout mode */
+	nautilus_icon_container_set_layout_mode (icon_container,
+						 gtk_widget_get_direction (GTK_WIDGET(icon_container)) == GTK_TEXT_DIR_RTL ?
+						 NAUTILUS_ICON_LAYOUT_R_L_T_B :
+						 NAUTILUS_ICON_LAYOUT_L_R_T_B);
 
 	if (!setup_sound_preview) {
 		eel_preferences_add_auto_enum (NAUTILUS_PREFERENCES_PREVIEW_SOUND,
 					       &preview_sound_auto_value);
-
-		eel_preferences_monitor_directory ("/desktop/gnome/sound");
-		eel_preferences_add_auto_boolean ("/desktop/gnome/sound/enable_esd",
-						  &gnome_esd_enabled_auto_value);
 		
 		setup_sound_preview = TRUE;
 	}
@@ -2714,8 +2688,8 @@ fm_icon_view_init (FMIconView *icon_view)
 						  labels_beside_icons_changed_callback,
 						  icon_view, G_OBJECT (icon_view));
 
-	g_signal_connect_object (get_icon_container (icon_view), "handle_url",
-				 G_CALLBACK (icon_view_handle_url), icon_view, 0);
+	g_signal_connect_object (get_icon_container (icon_view), "handle_netscape_url",
+				 G_CALLBACK (icon_view_handle_netscape_url), icon_view, 0);
 	g_signal_connect_object (get_icon_container (icon_view), "handle_uri_list",
 				 G_CALLBACK (icon_view_handle_uri_list), icon_view, 0);
 	g_signal_connect_object (get_icon_container (icon_view), "handle_text",
@@ -2735,10 +2709,10 @@ fm_icon_view_create (NautilusWindowInfo *window)
 
 static gboolean
 fm_icon_view_supports_uri (const char *uri,
-			   GnomeVFSFileType file_type,
+			   GFileType file_type,
 			   const char *mime_type)
 {
-	if (file_type == GNOME_VFS_FILE_TYPE_DIRECTORY) {
+	if (file_type == G_FILE_TYPE_DIRECTORY) {
 		return TRUE;
 	}
 	if (strcmp (mime_type, NAUTILUS_SAVED_SEARCH_MIMETYPE) == 0){
