@@ -28,6 +28,7 @@
 #define NAUTILUS_APPLICATION_H
 
 #include <gdk/gdk.h>
+#include <gio/gio.h>
 #include <bonobo/bonobo-generic-factory.h>
 #include <libnautilus-private/nautilus-undo-manager.h>
 
@@ -49,9 +50,15 @@ typedef struct NautilusWindow NautilusWindow;
 typedef struct _NautilusSpatialWindow NautilusSpatialWindow;
 #endif
 
+typedef struct NautilusShell NautilusShell;
+
 typedef struct {
 	BonoboGenericFactory parent;
 	NautilusUndoManager *undo_manager;
+	NautilusShell *shell;
+	gboolean shell_registered;
+	GVolumeMonitor *volume_monitor;
+	unsigned int automount_idle_id;
 } NautilusApplication;
 
 typedef struct {
@@ -69,19 +76,21 @@ void                 nautilus_application_startup           (NautilusApplication
 							     gboolean             browser_window,
 							     const char          *startup_id,
 							     const char          *default_geometry,
+							     const char          *session_to_load,
 							     const char          *urls[]);
 GList *              nautilus_application_get_window_list           (void);
 GList *              nautilus_application_get_spatial_window_list    (void);
+unsigned int         nautilus_application_get_n_windows            (void);
 
 NautilusWindow *     nautilus_application_present_spatial_window     (NautilusApplication *application,
 								      NautilusWindow      *requesting_window,
 								      const char          *startup_id,
-								      const char          *location,
+								      GFile               *location,
 								      GdkScreen           *screen);
 NautilusWindow *     nautilus_application_present_spatial_window_with_selection (NautilusApplication *application,
 										 NautilusWindow      *requesting_window,
 										 const char          *startup_id,
-										 const char          *location,
+										 GFile               *location,
 										 GList		     *new_selection,
 										 GdkScreen           *screen);
 
@@ -94,5 +103,6 @@ void                 nautilus_application_close_parent_windows     (NautilusSpat
 void                 nautilus_application_close_all_spatial_windows  (void);
 void                 nautilus_application_open_desktop      (NautilusApplication *application);
 void                 nautilus_application_close_desktop     (void);
-
+void                 nautilus_application_load_session      (NautilusApplication *application,
+							     const char *filename); 
 #endif /* NAUTILUS_APPLICATION_H */
